==> Cafeterra_2.0.3.tgz: install/Pg/d_attrdef.sql <==
--
-- Data for TOC Entry ID 5 (OID 17308)
--
-- Name: attrdef Type: TABLE DATA Owner: aliphe
--


INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('ORACLE_HOME','DBI','Oracle','connector','string','Oracle Home','--nodefault--',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('FIELD_SEP','all','CSV','connector','string','Field separator',';',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('RECORD_SEP','all','CSV','connector','string','Record separator','\\n',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('ESCAPE_CHAR','all','CSV','connector','string','Escape character','\\\\',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('QUOTE_CHAR','all','CSV','connector','string','Field delimiter','"',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('DIRECTORY','LFS','all','connector','string','Directory','',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('DIRECTORY','FTP','all','connector','string','Directory','',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('COLUMN_NAMES','all','CSV','connector','list','Column names in first row','no;yes;no',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('AutoCommit','DBI','all','connector','number','Autocommit','0','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('RaiseError','DBI','all','connector','number','RaiseError','1','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('PrintError','DBI','all','connector','number','PrintError','0','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('RECORD_TAG','all','XML','container','string','Recod tab','','');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('SHEETNAME','all','XCEL','container','atome','Sheet Name','','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('STARTCOL','all','XCEL','container','atome','First Column','','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('COLCOUNT','all','XCEL','container','atome','Columns Count','','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('STARTROW','all','XCEL','container','atome','First Row','','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('ROWSCOUNT','all','XCEL','container','atome','Rows Count','','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('FILENAME','all','XCEL','connector','atome','File Name','','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('TITLESROW','all','XCEL','container','atome','Titles Row','','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_PORT','all','all','webservice','number','Webservice Port','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_TYPE','all','all','webservice','list','Webservice Type','WS_SOAP;WS_SOAP;WS_XMLRPC','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_COMPRESSION','all','all','webservice','number','Webservice Compression threshold','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_HTTPS_CERT_FILE','all','all','webservice','string','Webservice SSL certificat file','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_HTTPS_KEY_FILE','all','all','webservice','string','Webservice SSL key file','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_AUTHTYPE','all','all','webservice','list','Webservice Authentification methode','WS_AUTH_NONE;WS_AUTH_NONE;WS_AUTH_TICKET','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_AUTH_TTL','all','all','webservice','number','Webservice Auth. Time To Live in seconds','60','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_PROTOCOL','all','all','webservice','list','Webservice Protocol','WS_PROTO_HTTP;WS_PROTO_HTTP;WS_PROTO_TCP;WS_PROTO_POP3','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_REUSEPORT','all','all','webservice','list','Webservice Reuse Port','0','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('HPRIM_MAINSEP','all','HPRIM','connector','atome','Hprim main separator','|','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('HPRIM_SUBSUBFIELDSEP','all','HPRIM','connector','atome','Hprim separator for sub sub fields','&','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('HPRIM_SUBFIELDSEP','all','HPRIM','connector','atome','Hprim separator for sub fields','~','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('HPRIM_REPEATER','all','HPRIM','connector','atome','Hprim separator for repeated fields','^','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('HPRIM_ESCAPECHAR','all','HPRIM','connector','atome','Hprim escape char','\\','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_ROOTDN','LDAP','LDAP','connector','atome','Ldap root dn',NULL,'no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_BASEDN','LDAP','LDAP','container','atome','Base dn for the container',NULL,'no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_BASEFILTER','LDAP','LDAP','container','atome','Base filter for the container','(objectclass=*)','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_DNATTRS','LDAP','LDAP','container','atome','Default attributes to create DNs for new entries','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_INSERTATTRS','LDAP','LDAP','container','atome','Default attributes values for new entries','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_SIZELIMIT','LDAP','LDAP','container','atome','Number of entries fetched by a query','0','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_TIMELIMIT','LDAP','LDAP','container','atome','Max duration of a query','0','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_INSEPARATOR','LDAP','LDAP','container','atome','Sep for multiples values when inserting',NULL,'no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_OUTSEPARATOR','LDAP','LDAP','container','atome','Sep for multiples values when fetching',NULL,'no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_FIRSTONLY','LDAP','LDAP','container','atome','For multiples retrieve first one only',NULL,'no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_SCOPE','LDAP','LDAP','container','list','Scope of the search','sub;sub;base;one','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('AutoCommit','LDAP','LDAP','connector','number','Autocommit','1','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_LOGINRULE','LDAP','LDAP','connector','atome','Ldap loginrule (eg cn=*,<ROOT>)','cn=*,<ROOT>','no');

INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_CHILDCOUNT','all','all','xmlsocket','list','Max number of childs','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_CHILDPORT','all','all','xmlsocket','list','Child port number','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_CLIENTPORT','all','all','xmlsocket','list','Client port number','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_HOSTALLOW','all','all','xmlsocket','list','Hosts allowed to connect','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_HOSTDENY','all','all','xmlsocket','list','Hosts not allowd to connect','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_MAXCHILDMSGSIZE','all','all','xmlsocket','list','Max size of messages from child','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_MAXCLIENTMSGSIZE','all','all','xmlsocket','list','Max size of messages from client','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_MAXMSGSIZE','all','all','xmlsocket','list','Max message size','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_RECSEP','all','all','xmlsocket','list','Record separator (see xmlsocket doc)','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_REUSE','all','all','xmlsocket','list','Reuse port','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_SCRIPTTO','all','all','xmlsocket','list','Script timeout','--nodefault--','no');

==> Cafeterra_2.0.5.tgz: install/Pg/d_attrdef.sql <==
--
-- Data for TOC Entry ID 5 (OID 17308)
--
-- Name: attrdef Type: TABLE DATA Owner: aliphe
--


INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('ORACLE_HOME','DBI','Oracle','connector','string','Oracle Home','--nodefault--',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('FIELD_SEP','all','CSV','connector','string','Field separator',';',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('RECORD_SEP','all','CSV','connector','string','Record separator','\\n',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('ESCAPE_CHAR','all','CSV','connector','string','Escape character','\\\\',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('QUOTE_CHAR','all','CSV','connector','string','Field delimiter','"',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('DIRECTORY','LFS','all','connector','string','Directory','',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('DIRECTORY','FTP','all','connector','string','Directory','',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('COLUMN_NAMES','all','CSV','connector','list','Column names in first row','no;yes;no',NULL);
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('AutoCommit','DBI','all','connector','number','Autocommit','0','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('RaiseError','DBI','all','connector','number','RaiseError','1','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('PrintError','DBI','all','connector','number','PrintError','0','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('RECORD_TAG','all','XML','container','string','Recod tab','','');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('SHEETNAME','all','XCEL','container','atome','Sheet Name','','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('STARTCOL','all','XCEL','container','atome','First Column','','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('COLCOUNT','all','XCEL','container','atome','Columns Count','','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('STARTROW','all','XCEL','container','atome','First Row','','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('ROWSCOUNT','all','XCEL','container','atome','Rows Count','','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('FILENAME','all','XCEL','connector','atome','File Name','','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('TITLESROW','all','XCEL','container','atome','Titles Row','','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_PORT','all','all','webservice','number','Webservice Port','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_TYPE','all','all','webservice','list','Webservice Type','WS_SOAP;WS_SOAP;WS_XMLRPC','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_COMPRESSION','all','all','webservice','number','Webservice Compression threshold','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_HTTPS_CERT_FILE','all','all','webservice','string','Webservice SSL certificat file','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_HTTPS_KEY_FILE','all','all','webservice','string','Webservice SSL key file','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_AUTHTYPE','all','all','webservice','list','Webservice Authentification methode','WS_AUTH_NONE;WS_AUTH_NONE;WS_AUTH_TICKET','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_AUTH_TTL','all','all','webservice','number','Webservice Auth. Time To Live in seconds','60','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_PROTOCOL','all','all','webservice','list','Webservice Protocol','WS_PROTO_HTTP;WS_PROTO_HTTP;WS_PROTO_TCP;WS_PROTO_POP3','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('WS_REUSEPORT','all','all','webservice','list','Webservice Reuse Port','0','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('HPRIM_MAINSEP','all','HPRIM','connector','atome','Hprim main separator','|','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('HPRIM_SUBSUBFIELDSEP','all','HPRIM','connector','atome','Hprim separator for sub sub fields','&','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('HPRIM_SUBFIELDSEP','all','HPRIM','connector','atome','Hprim separator for sub fields','~','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('HPRIM_REPEATER','all','HPRIM','connector','atome','Hprim separator for repeated fields','^','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('HPRIM_ESCAPECHAR','all','HPRIM','connector','atome','Hprim escape char','\\','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_ROOTDN','LDAP','LDAP','connector','atome','Ldap root dn',NULL,'no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_BASEDN','LDAP','LDAP','container','atome','Base dn for the container',NULL,'no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_BASEFILTER','LDAP','LDAP','container','atome','Base filter for the container','(objectclass=*)','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_DNATTRS','LDAP','LDAP','container','atome','Default attributes to create DNs for new entries','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_INSERTATTRS','LDAP','LDAP','container','atome','Default attributes values for new entries','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_SIZELIMIT','LDAP','LDAP','container','atome','Number of entries fetched by a query','0','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_TIMELIMIT','LDAP','LDAP','container','atome','Max duration of a query','0','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_INSEPARATOR','LDAP','LDAP','container','atome','Sep for multiples values when inserting',NULL,'no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_OUTSEPARATOR','LDAP','LDAP','container','atome','Sep for multiples values when fetching',NULL,'no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_FIRSTONLY','LDAP','LDAP','container','atome','For multiples retrieve first one only',NULL,'no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_SCOPE','LDAP','LDAP','container','list','Scope of the search','sub;sub;base;one','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('AutoCommit','LDAP','LDAP','connector','number','Autocommit','1','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('LDAP_LOGINRULE','LDAP','LDAP','connector','atome','Ldap loginrule (eg cn=*,<ROOT>)','cn=*,<ROOT>','no');

INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_CHILDCOUNT','all','all','xmlsocket','list','Max number of childs','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_CHILDPORT','all','all','xmlsocket','list','Child port number','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_CLIENTPORT','all','all','xmlsocket','list','Client port number','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_HOSTALLOW','all','all','xmlsocket','list','Hosts allowed to connect','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_HOSTDENY','all','all','xmlsocket','list','Hosts not allowd to connect','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_MAXCHILDMSGSIZE','all','all','xmlsocket','list','Max size of messages from child','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_MAXCLIENTMSGSIZE','all','all','xmlsocket','list','Max size of messages from client','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_MAXMSGSIZE','all','all','xmlsocket','list','Max message size','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_RECSEP','all','all','xmlsocket','list','Record separator (see xmlsocket doc)','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_REUSE','all','all','xmlsocket','list','Reuse port','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid", "protocolid", "driverid", "objtype", "datatype", "attrdeflabel", "attrdefault", "requiredattr") VALUES ('XS_SCRIPTTO','all','all','xmlsocket','list','Script timeout','--nodefault--','no');
INSERT INTO "attrdef" ("attrdefid","protocolid","driverid","objtype","datatype","attrdeflabel","attrdefault","requiredattr") VALUES ('GENERIC_OTHERS','DBI','Generic','connector','string','Additional dbi attributes eg : {ATT => VAL}','--nodefault--','no');
